@@ -7,8 +7,11 @@ from Tkinter import *
 from tkFont import *
 from ttk import *
 import tkMessageBox
+import webbrowser
 
-from cricket.widgets import ReadOnlyText
+from tkreadonly import ReadOnlyText
+
+from cricket import VERSION, NUM_VERSION
 from cricket.model import TestMethod, TestCase, TestModule
 from cricket.executor import Executor
 
@@ -90,9 +93,9 @@ class MainWindow(object):
         # Prevent the menus from having the empty tearoff entry
         self.root.option_add('*tearOff', FALSE)
         # Catch the close button
-        self.root.protocol("WM_DELETE_WINDOW", self.on_quit)
+        self.root.protocol("WM_DELETE_WINDOW", self.cmd_quit)
         # Catch the "quit" event.
-        self.root.createcommand('exit', self.on_quit)
+        self.root.createcommand('exit', self.cmd_quit)
 
         # Setup the menu
         self._setup_menubar()
@@ -134,11 +137,11 @@ class MainWindow(object):
         self.menu_file = Menu(self.menubar)
         self.menubar.add_cascade(menu=self.menu_file, label='File')
 
-        self.menu_edit = Menu(self.menubar)
-        self.menubar.add_cascade(menu=self.menu_edit, label='Edit')
+        self.menu_test = Menu(self.menubar)
+        self.menubar.add_cascade(menu=self.menu_test, label='Test')
 
-        # self.menu_help = Menu(self.menubar, name='help')
-        # self.menubar.add_cascade(menu=self.menu_help)
+        self.menu_help = Menu(self.menubar)
+        self.menubar.add_cascade(menu=self.menu_help, label='Help')
 
         # self.menu_Apple.add_command(label='Test', command=self.cmd_dummy)
 
@@ -146,11 +149,13 @@ class MainWindow(object):
         # self.menu_file.add_command(label='Open...', command=self.cmd_dummy)
         # self.menu_file.add_command(label='Close', command=self.cmd_dummy)
 
-        # self.menu_edit.add_command(label='New', command=self.cmd_dummy)
-        # self.menu_edit.add_command(label='Open...', command=self.cmd_dummy)
-        # self.menu_edit.add_command(label='Close', command=self.cmd_dummy)
+        self.menu_test.add_command(label='Run all', command=self.cmd_run_all)
+        self.menu_test.add_command(label='Run selected tests', command=self.cmd_run_selected)
+        self.menu_test.add_command(label='Re-run failed tests', command=self.cmd_rerun)
 
-        # self.menu_help.add_command(label='Test', command=self.cmd_dummy)
+        self.menu_help.add_command(label='Open Documentation', command=self.cmd_cricket_docs)
+        self.menu_help.add_command(label='Open Cricket project page', command=self.cmd_cricket_page)
+        self.menu_help.add_command(label='Open Cricket on GitHub', command=self.cmd_cricket_github)
 
         # last step - configure the menubar
         self.root['menu'] = self.menubar
@@ -166,17 +171,17 @@ class MainWindow(object):
         self.toolbar.grid(column=0, row=0, sticky=(W, E))
 
         # Buttons on the toolbar
-        self.stop_button = Button(self.toolbar, text='Stop', command=self.on_stop, state=DISABLED)
+        self.stop_button = Button(self.toolbar, text='Stop', command=self.cmd_stop, state=DISABLED)
         self.stop_button.grid(column=0, row=0)
 
-        self.run_all_button = Button(self.toolbar, text='Run all', command=self.on_run_all)
+        self.run_all_button = Button(self.toolbar, text='Run all', command=self.cmd_run_all)
         self.run_all_button.grid(column=1, row=0)
 
         self.run_selected_button = Button(self.toolbar, text='Run selected',
-            command=self.on_run_selected, state=DISABLED)
+            command=self.cmd_run_selected, state=DISABLED)
         self.run_selected_button.grid(column=2, row=0)
 
-        self.rerun_button = Button(self.toolbar, text='Re-run', command=self.on_rerun, state=DISABLED)
+        self.rerun_button = Button(self.toolbar, text='Re-run', command=self.cmd_rerun, state=DISABLED)
         self.rerun_button.grid(column=3, row=0)
 
         self.toolbar.columnconfigure(0, weight=0)
@@ -486,16 +491,73 @@ class MainWindow(object):
         self.root.mainloop()
 
     ######################################################
-    # GUI Callbacks
+    # User commands
     ######################################################
 
-    def on_quit(self):
-        "Event handler: Quit"
+    def cmd_quit(self):
+        "Command: Quit"
         # If the runner is currently running, kill it.
         self.stop()
 
         self.root.quit()
 
+    def cmd_stop(self, event=None):
+        "Command: The stop button has been pressed"
+        self.stop()
+
+    def cmd_run_all(self, event=None):
+        "Command: The Run all button has been pressed"
+        # If the executor isn't currently running, we can
+        # start a test run.
+        if not self.executor or not self.executor.is_running:
+            self.run(active=True)
+
+    def cmd_run_selected(self, event=None):
+        "Command: The 'run selected' button has been pressed"
+        current_tree = self.current_test_tree
+
+        # If a node is selected, it needs to be made active
+        for path in current_tree.selection():
+            parts = path.split('.')
+            testModule = self.project
+            for part in parts:
+                testModule = testModule[part]
+
+            testModule.set_active(True)
+
+        # If the executor isn't currently running, we can
+        # start a test run.
+        if not self.executor or not self.executor.is_running:
+            self.run(labels=set(current_tree.selection()))
+
+    def cmd_rerun(self, event=None):
+        "Command: The run/stop button has been pressed"
+        # If the executor isn't currently running, we can
+        # start a test run.
+        if not self.executor or not self.executor.is_running:
+            self.run(status=set(TestMethod.FAILING_STATES))
+
+    def cmd_cricket_page(self):
+        "Show the Cricket project page"
+        webbrowser.open_new('http://pybee.org/cricket/')
+
+    def cmd_cricket_github(self):
+        "Show the Cricket GitHub repo"
+        webbrowser.open_new('http://github.com/pybee/cricket')
+
+    def cmd_cricket_docs(self):
+        "Show the Cricket documentation"
+        # If this is a formal release, show the docs for that
+        # version. otherwise, just show the head docs.
+        if len(NUM_VERSION) == 3:
+            webbrowser.open_new('http://cricket.readthedocs.org/en/v%s/' % VERSION)
+        else:
+            webbrowser.open_new('http://cricket.readthedocs.org/')
+
+    ######################################################
+    # GUI Callbacks
+    ######################################################
+
     def on_testModuleClicked(self, event):
         "Event handler: a module has been clicked in the tree"
         parts = event.widget.focus().split('.')
@@ -665,42 +727,6 @@ class MainWindow(object):
                         has_children = True
                     node = node.parent
 
-    def on_stop(self, event=None):
-        "Event handler: The stop button has been pressed"
-        self.stop()
-
-    def on_run_all(self, event=None):
-        "Event handler: The Run all button has been pressed"
-        # If the executor isn't currently running, we can
-        # start a test run.
-        if not self.executor or not self.executor.is_running:
-            self.run(active=True)
-
-    def on_run_selected(self, event=None):
-        "Event handler: The 'run selected' button has been pressed"
-        current_tree = self.current_test_tree
-
-        # If a node is selected, it needs to be made active
-        for path in current_tree.selection():
-            parts = path.split('.')
-            testModule = self.project
-            for part in parts:
-                testModule = testModule[part]
-
-            testModule.set_active(True)
-
-        # If the executor isn't currently running, we can
-        # start a test run.
-        if not self.executor or not self.executor.is_running:
-            self.run(labels=set(current_tree.selection()))
-
-    def on_rerun(self, event=None):
-        "Event handler: The run/stop button has been pressed"
-        # If the executor isn't currently running, we can
-        # start a test run.
-        if not self.executor or not self.executor.is_running:
-            self.run(status=set(TestMethod.FAILING_STATES))
-
     def on_testProgress(self):
         "Event handler: a periodic update to poll the runner for output, generating GUI updates"
         if self.executor and self.executor.poll():
@@ -818,7 +844,6 @@ class MainWindow(object):
         else:
             self.run_selected_button.configure(state=DISABLED)
 
-
     ######################################################
     # GUI utility methods
     ######################################################
